//  Beispiel 7.2 "Erweiterung des Sketches 7.1 um einige Terminal-Befehle"
//               "und einer neuen Radio-Box-Gruppe zur Schrift-Farbauswahl."
//               "Außerdem erscheint eine Fehlermeldung, wenn keine WLAN-"
//               "Verbindung hergestellt werden konnte."
//  
//  Unter Verwendung der IoT32 Brick Library

#include <all_IoT32.h>


int counter = 0;
int currentGPIO = 0;                                                // 0 = Beide aus, 1 = 13 ein, 2 = 14 ein, 3 = Beide ein
int unicodeMode = 1;                                                // 0 = Asc II Namen, 1 = Unicode Namen
int displayMode = 1;                                                // 0 = Display aus,  1 = Display ein
int colorMode = 1;                                                  // 1 = Rote Schrift, 2 = Grüne Schrift, 3 = Blaue Schrift usw.

String vorname_web    = "(Vorname)";
String nachname_web   = "(Nachname)";


void setup()
{
  IoT_Init(true);
  IoT_WLANconnect(WiFiHotSpotName, WiFiHotSpotPassword);
  IoT_NTPinit();

  IoT_WebServer.on("/", handleRoot);                                // Sobald der Browser direkt auf das Stammverzeichnis zugreift, führe die Funktion handleRoot (siehe unten) aus.
  IoT_WebServer.on("/submit", handleSubmit);                        // Handler für die Eingabe der Namen in den Eingabefeldern
  IoT_WebServer.begin();                                            // ab jetzt "horcht" der Server auf HTTP-Anfragen
  Serial.println("HTTP server started");
}

void loop()
{
  IoT_Idle();

  IoT_WebServer.handleClient();                                     // Bediene die http Anfragen
  
  if (IoT_Keypress())                                               // Wenn Taster gedrückt wird, Konfiguration zeigen
  {
    IoT_DisplayWLANstatus();
    if (counter % 10 == 0)                                          // Infos seriell nicht zu oft ausgeben (ca. 1 Sekunde)
    {
      Serial.println(IoT_NTPdatetime() + " (" + IoT_NTPdaylightSavingTime(true) + ")");
      Serial.print("WiFi is ");
      Serial.print(IoT_WLANconnected() ? "connected" : "not connected");
      Serial.println(". Uptime: " + IoT_WLANuptime(true) + " seit " + IoT_WLANstartDatetime());
    }
  }
  else
  {
    IoT_Idle();
    if (counter % 25 == 0) //Infos seriell nicht zu oft ausgeben (ca. alle 2 Sekunden)
    {
      if (IoT_NTPeventAvail)                                        // Zeitevent triggern
      {
        IoT_NTPprintEvent(IoT_NTPcurrentEvent);
        IoT_NTPeventAvail = false;
      }
    }
    
    IoT_DisplayClear(16);                                           // OLED Display löschen (16 Punkt Schrift)
    IoT_DisplayAlignText(TEXT_ALIGN_CENTER);                        // Zentrierte Darstellung des Textes
    if (IoT_NTPvalid())                                             // Prüfen, ob eine gültige Uhrzeit aus dem Internet empfangen wurde
    {
      if (displayMode == 1)
      {
        IoT_DisplayDrawText(63, 0, IoT_NTPtime());                  // Uhrzeit im Display anzeigen
        IoT_DisplayDrawText(63, 15, IoT_NTPdate());                 // Datum im Display anzeigen
        IoT_Idle();
      }
    }
    else                                                            // "Bitte warten..." zentriert anzeigen
    {
      if (displayMode == 1)
      {
        if (IoT_WLANinited)
        {
          IoT_DisplayClear(24);                                     // OLED Display löschen (24 Punkt Schrift)
          IoT_DisplayAlignText(TEXT_ALIGN_CENTER);                  // Zentrierte Darstellung des Textes
          IoT_DisplayDrawText(64, 5, "Bitte");
          IoT_DisplayDrawText(64, 34, "warten...");
        }
        else
        {
          IoT_DisplayClear(24);                                     // OLED Display löschen (24 Punkt Schrift)
          IoT_DisplayAlignText(TEXT_ALIGN_CENTER);                  // Zentrierte Darstellung des Textes
          IoT_DisplayDrawText(64, 5, "Kein");
          IoT_DisplayDrawText(64, 34, "WLAN");
        }
      }
    }
  }
  IoT_DisplayUpdate();                                              // OLED-Anzeige aktualisieren
  delay(100);                                                       // 100 ms. warten
  t_TerminalRead();                                                 // Reset-Anforderung prüfen
  counter++;
}

//Mit der Funktion handleRoot() wird die Website ausgeliefert sobald eine Anfrage von einem Browser eintrifft

void handleRoot ()
{
  String time_web = IoT_NTPtime();
  String date_web = IoT_NTPdate();
  String ipaddr_web  = IoT_WLANaddress(false);
  String title_web = "Brick'R'knowledge IoT Brick-Website";
  int sec = millis() / 1000;
  int min = sec / 60;
  int hr = min / 60;
  String ColorHexVal = "";
  switch (colorMode)
  {
    case 1:
      ColorHexVal = "#FF0000";
      break;
    case 2:
      ColorHexVal = "#00FF00";
      break;
    case 3:
      ColorHexVal = "#0000FF";
      break;
    case 4:
      ColorHexVal = "#00FFFF";
      break;
    case 5:
      ColorHexVal = "#FF00FF";
      break;
    case 6:
      ColorHexVal = "#FFFF00";
      break;
    case 7:
      ColorHexVal = "#000000";
      break;
    default:
      ColorHexVal = "#000000";
      break;
  }
  String content =                                                  // Die HTML-Seite in lesbarer Formatierung,
                                                                    // darf auch Variablen enthalten
"<html>\
  <head>\
    <title>" + title_web + "</title>\
    <style>\
      body { background-color: #FFFFFF; font-family: Menlo, Monaco, Courier, monospace; Color: " + ColorHexVal + "; }\
    </style>\
    <style type='text/css'>\
      h1 { font-family: Arial, 'Helvetica Neue', Helvetica, sans-serif; Color: #000088; }\
    </style>\
  </head>\
  <body>\
    <h1>" + title_web + "</h1>\
    <p>Datum: &nbsp; &nbsp;  &nbsp;  &nbsp;" + date_web + "</p>\
    <p>Uhrzeit: &nbsp;  &nbsp;  &nbsp;" + time_web + "</p>\
    <p>IP-Addresse: &nbsp;" + ipaddr_web + "</p>\
    <p>Letzter Name: " + vorname_web + " " + nachname_web + "</p>\
    <form action = 'http://" + ipaddr_web + "/submit' method='POST'>\
      Vorname:&nbsp; <input type='text' name='vname' value=''><br>\
      Nachname: <input type='text' name='nname' value=''><br>\
      <br>\
      <input type='checkbox' name='unicode' value='chkd' checked> Unicode-Zeichen im Namen erlauben<br>\
      <input type='checkbox' name='display' value='chkd' checked> OLED-Display eingeschaltet<br>\
      <br>\
      <input type='radio' id='led0' name='LEDgroup' value='none' checked> Keinen Ausgang einschalten<br>\
      <input type='radio' id='led1' name='LEDgroup' value='GPIO23'> GPIO 23 einschalten<br>\
      <input type='radio' id='led2' name='LEDgroup' value='GPIO18'> GPIO 18 einschalten<br>\
      <input type='radio' id='led3' name='LEDgroup' value='both'> Beide Ausg&auml;nge einschalten<br>\
      <br>\
      <input type='radio' id='color1' name='COLORgroup' value='red' checked> Rote Schrift<br>\
      <input type='radio' id='color2' name='COLORgroup' value='green'> Gr&uuml;ne Schrift<br>\
      <input type='radio' id='color3' name='COLORgroup' value='blue'> Blaue Schrift<br>\
      <input type='radio' id='color4' name='COLORgroup' value='cyan'> T&uuml;rkise Schrift<br>\
      <input type='radio' id='color5' name='COLORgroup' value='magenta'> Violette Schrift<br>\
      <input type='radio' id='color6' name='COLORgroup' value='yellow'> Gelbe Schrift<br>\
      <input type='radio' id='color7' name='COLORgroup' value='black'> Schwarze Schrift<br>\
      <br>\
      <input type = 'submit' value='Namen im Terminal und auf der Webseite anzeigen, GPIO & Display schalten'><br>\
    </form>\
  </body>\
</html>";

  IoT_WebServer.send(200, "text/html", content);                    // HTTP-Statuscode 200 = OK (Anfrage wurde erfolgreich bearbeitet)
}

void handleSubmit ()
{
  Serial.println("Button wurde betaetigt");
  IoT_WebPrintAllFields();                                          // Alle gefundenen Felder auf dem Terminal ausgeben
  if (IoT_WebTestField("vname"))                                    // Testen, ob ein Feld mit dem Namen "vname" existiert
  {
    vorname_web = IoT_WebGetField("vname");                         // Das Web-Feld "vname" auslesen
  }
  if (IoT_WebTestField("nname"))                                    // Testen, ob ein Feld mit dem Namen "vname" existiert
  {
    nachname_web = IoT_WebGetField("nname");                        // Das Web-Feld "nname" auslesen
  }
  unicodeMode = boolval(IoT_WebTestField("unicode"));               // Testen, ob die Checkbox mit dem Namen "unicode" angekreuzt wurde
  displayMode = boolval(IoT_WebTestField("display"));               // Testen, ob die Checkbox mit dem Namen "display" angekreuzt wurde
  if (IoT_WebTestField("LEDgroup"))                                 // Testen, ob Felder mit dem Namen "LEDgroup" existieren
  {
    String selection = IoT_WebGetField("LEDgroup");
    if (selection == "none")                                        // Beide Leitungen aus
    {
      digitalWrite(23, LOW);
      digitalWrite(18, LOW);
      currentGPIO = 0;
    }
    else if (selection == "GPIO23")                                 // GPIO 23
    {
      digitalWrite(23, HIGH);
      digitalWrite(18, LOW);
      currentGPIO = 1;
    }
    else if (selection == "GPIO18")                                 // GPIO 18
    {
      digitalWrite(23, LOW);
      digitalWrite(18, HIGH);
      currentGPIO = 2;
    }
    else if (selection == "both")                                   // Beide Leitungen ein
    {
      digitalWrite(23, HIGH);
      digitalWrite(18, HIGH);
      currentGPIO = 3;
    }
  }
  if (IoT_WebTestField("COLORgroup"))                               // Testen, ob Felder mit dem Namen "COLORgroup" existieren
  {
    String selection = IoT_WebGetField("COLORgroup");
    if (selection == "red")                                         // Rot
    {
      colorMode = 1;
    }
    else if (selection == "green")                                 // Grün
    {
      colorMode = 2;
    }
    else if (selection == "blue")                                   // Blau
    {
      colorMode = 3;
    }
    else if (selection == "cyan")                                   // Türkis
    {
      colorMode = 4;
    }
    else if (selection == "magenta")                                // Violett
    {
      colorMode = 5;
    }
    else if (selection == "yellow")                                 // Gelb
    {
      colorMode = 6;
    }
    else if (selection == "black")                                  // Schwarz
    {
      colorMode = 7;
    }
  }
  if (unicodeMode == 0)
  {
    vorname_web  = cleanasc(vorname_web);
    nachname_web = cleanasc(nachname_web);
  }
  handleRoot();                                                     // Wieder auf die Hauptseite zurück schalten
}

